const config = require('config')
const helpers = require('./helpers')
const SendEmail = require('@pubsweet/component-send-email')
const logger = require('@pubsweet/logger')

class Email {
  constructor({
    type = 'system',
    toUser = {
      id: '',
      email: '',
      name: '',
    },
    content = {
      subject: '',
      ctaLink: '',
      ctaText: '',
      signatureName: '',
      unsubscribeLink: '',
      signatureJournal: '',
    },
  }) {
    this.type = type
    this.toUser = toUser
    this.content = content
  }

  set _toUser(newToUser) {
    this.toUser = newToUser
  }

  set _subject(newSubject) {
    this.subject = newSubject
  }

  set _content(newContent) {
    this.content = newContent
  }

  getBody({ body = {}, isReviewerInvitation = false }) {
    if (isReviewerInvitation) {
      return {
        html: helpers.getInvitationBody({
          replacements: {
            toUserName: this.toUser.name,
            ...this.content,
            ...body,
          },
        }),
        text: `${this.content.signatureName}`,
      }
    }

    return {
      html: helpers.getNotificationBody({
        replacements: {
          ...body,
          toUserName: this.toUser.name,
          ...this.content,
        },
      }),
      text: `${body.paragraph} ${this.content.ctaLink} ${
        this.content.ctaText
      } ${this.content.signatureName}`,
    }
  }

  sendEmail({ text, html }) {
    const fromEmail = config.get('mailer.from')
    const mailData = {
      from: fromEmail,
      to: this.toUser.email,
      subject: this.content.subject,
      text,
      html,
    }

    logger.info(
      `EMAIL: Sent email from ${fromEmail} to ${
        this.toUser.email
      } with subject '${this.content.subject}'`,
    )
    SendEmail.send(mailData)
  }
}

module.exports = Email
